/*    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: unlink.c,v 1.1.1.1 1999/10/15 22:49:23 nmav Exp $ */

#include <unlink.h>
#include <locks.h>
#include <random.h>
#include <errors.h>

static char rcsid[] = "$Id: unlink.c,v 1.1.1.1 1999/10/15 22:49:23 nmav Exp $";

/* Whether this function succeeds is highly depended on the hard disk's
 * behaviour (cache). 
 */


int u_unlink(char *filename)
{
#ifdef HAVE_STAT
	struct stat buf;
	int x;
	unsigned long i;
	unsigned char what_to_write;
	FILE *fstream;
	char tmp[256];

	x = stat(filename, &buf);
	if (x != 0)
		return x;
	if (buf.st_nlink > 1)
		fprintf(stderr, _("File %s has more than one hard links. Now they are unusable.\n"), filename);


	fstream = fopen(filename, "wb");
	if (fstream == NULL) {
		perror("fopen");
		return 1;
	}
/*
   if (read_lock( fileno((FILE*)fstream))==-1) {
   perror("lock");
   fprintf(stderr, "File %s cannot be removed (it is locked).\n", filename);
   return 1;
   }
 */
	if (fseek(fstream, 0, SEEK_SET) == -1) {
		perror("fseek");
		return 1;
	}
	what_to_write = '\0';

	for (i = 0; i < (buf.st_size); i++) {
		if (fwrite(&what_to_write, 1, sizeof(what_to_write), fstream) == 0) {
			perror("fwrite");
			return 1;
		}
	}

	fflush(fstream);
#ifdef HAVE_FSYNC
	fsync(fileno((FILE *) fstream));
#endif

/*  unlock( fileno((FILE*)fstream) );   */
	fclose(fstream);

#endif				/* STAT */

/* If stat() does not exist then we just remove the file. sorry
 */

	remove(filename);
	sprintf(tmp, _("File %s was deleted.\n"), filename);
	err_warn(tmp);
	return 0;
}
